Summary method for class “tsgarch.estimate”
# S3 method for tsgarch.estimate
summary(object, digits = 4, vcov_type = "H", include_persistence = TRUE, ...)A list with summary information of class “summary.tsgarch.estimate”.
an object of class “tsgarch.estimate”.
integer, used for number formatting. Optionally, to avoid scientific notation, set ‘options(scipen=999)’.
the type of standard errors based on the vcov estimate (see vcov).
whether to include the estimate of the persistence and
its calculated standard errors (calculated using the sdreport)
in the output.
not currently used.